@@ -19,7 +19,7 @@ API_RESPONSE_LAST_TIME = "lastTs"
 API_RESPONSE_POSTAL_CODE = "postalCode"
 API_RESPONSE_QUERY = "query"
 API_RESPONSE_RATE = "rate"
-API_RESPONSE_STANDING_CHARGE = "standing"
+API_RESPONSE_STANDING_CHARGE = "standingCharge"
 API_RESPONSE_START = "from"
 API_RESPONSE_TARIFF_STRUCTURE = "structure"
 API_RESPONSE_UNIT = "units"
